<?php
	$_SESSION['nume_slogan'] = '<b>Primaria Comunei Fratesti Judet Giurgiu</b><br /><br />Aplicatie Dedicata Informarii Consilierilor, Membrii Consililui Local (ADICMCL)<br />Versiune 1.0';
	$_SESSION['nume_antet'] = '<a href="http://'.$_SERVER['SERVER_NAME'].'">
					<img id="fotoheaderdreapta" alt="'.$_SERVER['SERVER_NAME'].'" title="'.$_SERVER['SERVER_NAME'].'" src="http://'.$_SERVER['SERVER_NAME'].'/img/logo.jpeg" />
					</a>';
	
	$_SESSION['nume_pag1'] = '<br>Acasa';
	$_SESSION['nume_pag2'] = '<br>Acasa';
	$_SESSION['nume_pag3'] = 'Proiecte pe Comisii de specialitate';
	$_SESSION['nume_pag4'] = '<br>Deconectare';
	$_SESSION['nume_pag5'] = '';
	
	$_SESSION['nume_pag1a'] = 'Sedinta<br>noua';
	$_SESSION['nume_pag1b'] = '<br>Acasa';
	$_SESSION['nume_pag2a'] = 'Proiecte<br>Sedinta';
	$_SESSION['nume_pag3a'] = 'Comisii<br>specialitate';
	$_SESSION['nume_pag4a'] = '<br>Deconectare';
	$_SESSION['nume_pag5a'] = '5a';
	
	$_SESSION['textareacontinut1'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut2'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut3'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut4'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut5'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	
	$_SESSION['textareacontinut1a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut2a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut3a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut4a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	$_SESSION['textareacontinut5a'] = 'Aplicatie dedicata Primaria Municipiului Giurgiu';
	
	$_SESSION['comisie1'] = 'Comisia de studii, Dezvoltare Economico-Sociala, Investitii, Buget-Finante, Administrarea Domeniului Public si Privat, Amenajarea Teritoriului si Urbanism, Dezvoltare Regionala si Integrare Europeana';
	$_SESSION['comisie2'] = 'Comisia ppentru Invatamant, Sanatate, Cultura, Protectie Sociala, Sport, Agrement, Protectia Mediului si Probleme de Culte';
	$_SESSION['comisie3'] = 'Comisia pentru Administratie Publica Locala, Juridic, Apararea Ordinii si LInistii Publice, Respectarea Drepturilor si Libertatilor Cetatenilor';
	$_SESSION['comisie4'] = '';
	$_SESSION['comisie5'] = '';
	
	if($_SESSION['nr_incercari'] == ''){$_SESSION['nr_incercari'] = '0';}
	$_SESSION['nr_incercari_permise'] = '8';
?>
