
<table id="casetaheader">
	<tr>
		<td id="headerstanga">
			<?php
				echo $_SESSION['nume_antet'];
			?>		
			
		</td>
		<td id="headerdreapta">
			<?php
				echo $_SESSION['nume_slogan'];
			?>				
		</td>
	<tr>
</table>